@@ -6,7 +6,7 @@ app.use(bodyParser.json());
 app.post('/', function (req, res) {
     const exported = require('./../out/ssr');
     const renderStart = performance.now();
-    if (exported[req.body.component]) {
+    if (!exported[req.body.component]) {
         console.error(`Component ${req.body.component} is not in exported.js.`);
         res.send(JSON.stringify({html: ''}));
         return;
