@@ -17,15 +17,20 @@ class Command(BaseCommand):
         with open(os.path.join(SVELTE_PROJECT_PATH, 'package.json'), 'r') as pkg_f:
             pkg_json = json.load(pkg_f)
             managepy_rel_path = os.path.relpath(settings.BASE_DIR, SVELTE_PROJECT_PATH)
+
             pkg_json['dependencies']['npm-run-all'] = "*"
             pkg_json['dependencies']['cross-env'] = "*"
             pkg_json['dependencies']['express'] = "*"
             pkg_json['dependencies']['body-parser'] = "*"
-            pkg_json['scripts']['dev'] = "run-p -l dev:django dev:dom dev:ssr dev:renderer"
-            pkg_json['scripts']['dev:django'] = f"cross-env python {managepy_rel_path}/manage.py runserver"
-            pkg_json['scripts']['dev:dom'] = "cross-env BUILD_TYPE=DOM rollup -c -w"
-            pkg_json['scripts']['dev:ssr'] = "cross-env BUILD_TYPE=RENDERER rollup ./src/exported.js -c -w"
-            pkg_json['scripts']['dev:renderer'] = "cross-env node ./scripts/renderer.js"
+
+            if 'dev' in pkg_json['scripts'] and 'run-p' in pkg_json['scripts']['dev']:
+                self.stdout.write("Looks like `package.json` is correctly provisioned.")
+            else:
+                pkg_json['scripts']['dev'] = "run-p -l dev:django dev:dom dev:ssr dev:renderer"
+                pkg_json['scripts']['dev:django'] = f"cross-env python {managepy_rel_path}/manage.py runserver"
+                pkg_json['scripts']['dev:dom'] = "cross-env BUILD_TYPE=DOM rollup -c -w"
+                pkg_json['scripts']['dev:ssr'] = "cross-env BUILD_TYPE=RENDERER rollup ./src/exported.js -c -w"
+                pkg_json['scripts']['dev:renderer'] = "cross-env node ./scripts/renderer.js"
 
             os.makedirs(os.path.join(SVELTE_PROJECT_PATH, "scripts"), exist_ok=True)
             os.makedirs(os.path.join(SVELTE_PROJECT_PATH, "src"), exist_ok=True)
